@@ -1,4 +1,3 @@
-import enum
 import errno
 from http import client, HTTPStatus
 import io
@@ -8,17 +7,15 @@ import array
 import re
 import socket
 import threading
+import warnings
 
 import unittest
 from unittest import mock
 TestCase = unittest.TestCase
 
 from test import support
-from test.support import os_helper
 from test.support import socket_helper
 
-support.requires_working_socket(module=True)
-
 here = os.path.dirname(__file__)
 # Self-signed cert file for 'localhost'
 CERT_localhost = os.path.join(here, 'keycert.pem')
@@ -524,195 +521,6 @@ class BasicTest(TestCase):
         # see issue40084
         self.assertTrue({'description', 'name', 'phrase', 'value'} <= set(dir(HTTPStatus(404))))
 
-    def test_simple_httpstatus(self):
-        class CheckedHTTPStatus(enum.IntEnum):
-            """HTTP status codes and reason phrases
-
-            Status codes from the following RFCs are all observed:
-
-                * RFC 7231: Hypertext Transfer Protocol (HTTP/1.1), obsoletes 2616
-                * RFC 6585: Additional HTTP Status Codes
-                * RFC 3229: Delta encoding in HTTP
-                * RFC 4918: HTTP Extensions for WebDAV, obsoletes 2518
-                * RFC 5842: Binding Extensions to WebDAV
-                * RFC 7238: Permanent Redirect
-                * RFC 2295: Transparent Content Negotiation in HTTP
-                * RFC 2774: An HTTP Extension Framework
-                * RFC 7725: An HTTP Status Code to Report Legal Obstacles
-                * RFC 7540: Hypertext Transfer Protocol Version 2 (HTTP/2)
-                * RFC 2324: Hyper Text Coffee Pot Control Protocol (HTCPCP/1.0)
-                * RFC 8297: An HTTP Status Code for Indicating Hints
-                * RFC 8470: Using Early Data in HTTP
-            """
-            def __new__(cls, value, phrase, description=''):
-                obj = int.__new__(cls, value)
-                obj._value_ = value
-
-                obj.phrase = phrase
-                obj.description = description
-                return obj
-
-            @property
-            def is_informational(self):
-                return 100 <= self <= 199
-
-            @property
-            def is_success(self):
-                return 200 <= self <= 299
-
-            @property
-            def is_redirection(self):
-                return 300 <= self <= 399
-
-            @property
-            def is_client_error(self):
-                return 400 <= self <= 499
-
-            @property
-            def is_server_error(self):
-                return 500 <= self <= 599
-
-            # informational
-            CONTINUE = 100, 'Continue', 'Request received, please continue'
-            SWITCHING_PROTOCOLS = (101, 'Switching Protocols',
-                    'Switching to new protocol; obey Upgrade header')
-            PROCESSING = 102, 'Processing'
-            EARLY_HINTS = 103, 'Early Hints'
-            # success
-            OK = 200, 'OK', 'Request fulfilled, document follows'
-            CREATED = 201, 'Created', 'Document created, URL follows'
-            ACCEPTED = (202, 'Accepted',
-                'Request accepted, processing continues off-line')
-            NON_AUTHORITATIVE_INFORMATION = (203,
-                'Non-Authoritative Information', 'Request fulfilled from cache')
-            NO_CONTENT = 204, 'No Content', 'Request fulfilled, nothing follows'
-            RESET_CONTENT = 205, 'Reset Content', 'Clear input form for further input'
-            PARTIAL_CONTENT = 206, 'Partial Content', 'Partial content follows'
-            MULTI_STATUS = 207, 'Multi-Status'
-            ALREADY_REPORTED = 208, 'Already Reported'
-            IM_USED = 226, 'IM Used'
-            # redirection
-            MULTIPLE_CHOICES = (300, 'Multiple Choices',
-                'Object has several resources -- see URI list')
-            MOVED_PERMANENTLY = (301, 'Moved Permanently',
-                'Object moved permanently -- see URI list')
-            FOUND = 302, 'Found', 'Object moved temporarily -- see URI list'
-            SEE_OTHER = 303, 'See Other', 'Object moved -- see Method and URL list'
-            NOT_MODIFIED = (304, 'Not Modified',
-                'Document has not changed since given time')
-            USE_PROXY = (305, 'Use Proxy',
-                'You must use proxy specified in Location to access this resource')
-            TEMPORARY_REDIRECT = (307, 'Temporary Redirect',
-                'Object moved temporarily -- see URI list')
-            PERMANENT_REDIRECT = (308, 'Permanent Redirect',
-                'Object moved permanently -- see URI list')
-            # client error
-            BAD_REQUEST = (400, 'Bad Request',
-                'Bad request syntax or unsupported method')
-            UNAUTHORIZED = (401, 'Unauthorized',
-                'No permission -- see authorization schemes')
-            PAYMENT_REQUIRED = (402, 'Payment Required',
-                'No payment -- see charging schemes')
-            FORBIDDEN = (403, 'Forbidden',
-                'Request forbidden -- authorization will not help')
-            NOT_FOUND = (404, 'Not Found',
-                'Nothing matches the given URI')
-            METHOD_NOT_ALLOWED = (405, 'Method Not Allowed',
-                'Specified method is invalid for this resource')
-            NOT_ACCEPTABLE = (406, 'Not Acceptable',
-                'URI not available in preferred format')
-            PROXY_AUTHENTICATION_REQUIRED = (407,
-                'Proxy Authentication Required',
-                'You must authenticate with this proxy before proceeding')
-            REQUEST_TIMEOUT = (408, 'Request Timeout',
-                'Request timed out; try again later')
-            CONFLICT = 409, 'Conflict', 'Request conflict'
-            GONE = (410, 'Gone',
-                'URI no longer exists and has been permanently removed')
-            LENGTH_REQUIRED = (411, 'Length Required',
-                'Client must specify Content-Length')
-            PRECONDITION_FAILED = (412, 'Precondition Failed',
-                'Precondition in headers is false')
-            REQUEST_ENTITY_TOO_LARGE = (413, 'Request Entity Too Large',
-                'Entity is too large')
-            REQUEST_URI_TOO_LONG = (414, 'Request-URI Too Long',
-                'URI is too long')
-            UNSUPPORTED_MEDIA_TYPE = (415, 'Unsupported Media Type',
-                'Entity body in unsupported format')
-            REQUESTED_RANGE_NOT_SATISFIABLE = (416,
-                'Requested Range Not Satisfiable',
-                'Cannot satisfy request range')
-            EXPECTATION_FAILED = (417, 'Expectation Failed',
-                'Expect condition could not be satisfied')
-            IM_A_TEAPOT = (418, 'I\'m a Teapot',
-                'Server refuses to brew coffee because it is a teapot.')
-            MISDIRECTED_REQUEST = (421, 'Misdirected Request',
-                'Server is not able to produce a response')
-            UNPROCESSABLE_ENTITY = 422, 'Unprocessable Entity'
-            LOCKED = 423, 'Locked'
-            FAILED_DEPENDENCY = 424, 'Failed Dependency'
-            TOO_EARLY = 425, 'Too Early'
-            UPGRADE_REQUIRED = 426, 'Upgrade Required'
-            PRECONDITION_REQUIRED = (428, 'Precondition Required',
-                'The origin server requires the request to be conditional')
-            TOO_MANY_REQUESTS = (429, 'Too Many Requests',
-                'The user has sent too many requests in '
-                'a given amount of time ("rate limiting")')
-            REQUEST_HEADER_FIELDS_TOO_LARGE = (431,
-                'Request Header Fields Too Large',
-                'The server is unwilling to process the request because its header '
-                'fields are too large')
-            UNAVAILABLE_FOR_LEGAL_REASONS = (451,
-                'Unavailable For Legal Reasons',
-                'The server is denying access to the '
-                'resource as a consequence of a legal demand')
-            # server errors
-            INTERNAL_SERVER_ERROR = (500, 'Internal Server Error',
-                'Server got itself in trouble')
-            NOT_IMPLEMENTED = (501, 'Not Implemented',
-                'Server does not support this operation')
-            BAD_GATEWAY = (502, 'Bad Gateway',
-                'Invalid responses from another server/proxy')
-            SERVICE_UNAVAILABLE = (503, 'Service Unavailable',
-                'The server cannot process the request due to a high load')
-            GATEWAY_TIMEOUT = (504, 'Gateway Timeout',
-                'The gateway server did not receive a timely response')
-            HTTP_VERSION_NOT_SUPPORTED = (505, 'HTTP Version Not Supported',
-                'Cannot fulfill request')
-            VARIANT_ALSO_NEGOTIATES = 506, 'Variant Also Negotiates'
-            INSUFFICIENT_STORAGE = 507, 'Insufficient Storage'
-            LOOP_DETECTED = 508, 'Loop Detected'
-            NOT_EXTENDED = 510, 'Not Extended'
-            NETWORK_AUTHENTICATION_REQUIRED = (511,
-                'Network Authentication Required',
-                'The client needs to authenticate to gain network access')
-        enum._test_simple_enum(CheckedHTTPStatus, HTTPStatus)
-
-    def test_httpstatus_range(self):
-        """Checks that the statuses are in the 100-599 range"""
-
-        for member in HTTPStatus.__members__.values():
-            self.assertGreaterEqual(member, 100)
-            self.assertLessEqual(member, 599)
-
-    def test_httpstatus_category(self):
-        """Checks that the statuses belong to the standard categories"""
-
-        categories = (
-            ((100, 199), "is_informational"),
-            ((200, 299), "is_success"),
-            ((300, 399), "is_redirection"),
-            ((400, 499), "is_client_error"),
-            ((500, 599), "is_server_error"),
-        )
-        for member in HTTPStatus.__members__.values():
-            for (lower, upper), category in categories:
-                category_indicator = getattr(member, category)
-                if lower <= member <= upper:
-                    self.assertTrue(category_indicator)
-                else:
-                    self.assertFalse(category_indicator)
-
     def test_status_lines(self):
         # Test HTTP status lines
 
@@ -788,33 +596,6 @@ class BasicTest(TestCase):
         resp.close()
         self.assertTrue(resp.closed)
 
-    def test_partial_reads_past_end(self):
-        # if we have Content-Length, clip reads to the end
-        body = "HTTP/1.1 200 Ok\r\nContent-Length: 4\r\n\r\nText"
-        sock = FakeSocket(body)
-        resp = client.HTTPResponse(sock)
-        resp.begin()
-        self.assertEqual(resp.read(10), b'Text')
-        self.assertTrue(resp.isclosed())
-        self.assertFalse(resp.closed)
-        resp.close()
-        self.assertTrue(resp.closed)
-
-    def test_partial_readintos_past_end(self):
-        # if we have Content-Length, clip readintos to the end
-        body = "HTTP/1.1 200 Ok\r\nContent-Length: 4\r\n\r\nText"
-        sock = FakeSocket(body)
-        resp = client.HTTPResponse(sock)
-        resp.begin()
-        b = bytearray(10)
-        n = resp.readinto(b)
-        self.assertEqual(n, 4)
-        self.assertEqual(bytes(b)[:4], b'Text')
-        self.assertTrue(resp.isclosed())
-        self.assertFalse(resp.closed)
-        resp.close()
-        self.assertTrue(resp.closed)
-
     def test_partial_reads_no_content_length(self):
         # when no length is present, the socket should be gracefully closed when
         # all data was read
@@ -1641,9 +1422,9 @@ class OfflineTest(TestCase):
         expected = {"responses"}  # Allowlist documented dict() object
         # HTTPMessage, parse_headers(), and the HTTP status code constants are
         # intentionally omitted for simplicity
-        denylist = {"HTTPMessage", "parse_headers"}
+        blacklist = {"HTTPMessage", "parse_headers"}
         for name in dir(client):
-            if name.startswith("_") or name in denylist:
+            if name.startswith("_") or name in blacklist:
                 continue
             module_object = getattr(client, name)
             if getattr(module_object, "__module__", None) == "http.client":
@@ -1976,7 +1757,7 @@ class HTTPSTest(TestCase):
         self.assertEqual(exc_info.exception.reason, 'CERTIFICATE_VERIFY_FAILED')
 
     def test_local_good_hostname(self):
-        # The (valid) cert validates the HTTPS hostname
+        # The (valid) cert validates the HTTP hostname
         import ssl
         server = self.make_server(CERT_localhost)
         context = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
@@ -1989,7 +1770,7 @@ class HTTPSTest(TestCase):
         self.assertEqual(resp.status, 404)
 
     def test_local_bad_hostname(self):
-        # The (valid) cert doesn't validate the HTTPS hostname
+        # The (valid) cert doesn't validate the HTTP hostname
         import ssl
         server = self.make_server(CERT_fakehostname)
         context = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
@@ -1997,21 +1778,38 @@ class HTTPSTest(TestCase):
         h = client.HTTPSConnection('localhost', server.port, context=context)
         with self.assertRaises(ssl.CertificateError):
             h.request('GET', '/')
-
-        # Same with explicit context.check_hostname=True
-        context.check_hostname = True
-        h = client.HTTPSConnection('localhost', server.port, context=context)
+        # Same with explicit check_hostname=True
+        with support.check_warnings(('', DeprecationWarning)):
+            h = client.HTTPSConnection('localhost', server.port,
+                                       context=context, check_hostname=True)
         with self.assertRaises(ssl.CertificateError):
             h.request('GET', '/')
-
-        # With context.check_hostname=False, the mismatching is ignored
+        # With check_hostname=False, the mismatching is ignored
         context.check_hostname = False
-        h = client.HTTPSConnection('localhost', server.port, context=context)
+        with support.check_warnings(('', DeprecationWarning)):
+            h = client.HTTPSConnection('localhost', server.port,
+                                       context=context, check_hostname=False)
         h.request('GET', '/nonexistent')
         resp = h.getresponse()
         resp.close()
         h.close()
         self.assertEqual(resp.status, 404)
+        # The context's check_hostname setting is used if one isn't passed to
+        # HTTPSConnection.
+        context.check_hostname = False
+        h = client.HTTPSConnection('localhost', server.port, context=context)
+        h.request('GET', '/nonexistent')
+        resp = h.getresponse()
+        self.assertEqual(resp.status, 404)
+        resp.close()
+        h.close()
+        # Passing check_hostname to HTTPSConnection should override the
+        # context's setting.
+        with support.check_warnings(('', DeprecationWarning)):
+            h = client.HTTPSConnection('localhost', server.port,
+                                       context=context, check_hostname=True)
+        with self.assertRaises(ssl.CertificateError):
+            h.request('GET', '/')
 
     @unittest.skipIf(not hasattr(client, 'HTTPSConnection'),
                      'http.client.HTTPSConnection not available')
@@ -2047,9 +1845,11 @@ class HTTPSTest(TestCase):
         self.assertIs(h._context, context)
         self.assertFalse(h._context.post_handshake_auth)
 
-        context = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT, cert_file=CERT_localhost)
-        context.post_handshake_auth = True
-        h = client.HTTPSConnection('localhost', 443, context=context)
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore', 'key_file, cert_file and check_hostname are deprecated',
+                                    DeprecationWarning)
+            h = client.HTTPSConnection('localhost', 443, context=context,
+                                       cert_file=CERT_localhost)
         self.assertTrue(h._context.post_handshake_auth)
 
 
@@ -2121,10 +1921,10 @@ class RequestBodyTest(TestCase):
         self.assertEqual(b'body\xc1', f.read())
 
     def test_text_file_body(self):
-        self.addCleanup(os_helper.unlink, os_helper.TESTFN)
-        with open(os_helper.TESTFN, "w", encoding="utf-8") as f:
+        self.addCleanup(support.unlink, support.TESTFN)
+        with open(support.TESTFN, "w") as f:
             f.write("body")
-        with open(os_helper.TESTFN, encoding="utf-8") as f:
+        with open(support.TESTFN) as f:
             self.conn.request("PUT", "/url", f)
             message, f = self.get_headers_and_fp()
             self.assertEqual("text/plain", message.get_content_type())
@@ -2136,10 +1936,10 @@ class RequestBodyTest(TestCase):
             self.assertEqual(b'4\r\nbody\r\n0\r\n\r\n', f.read())
 
     def test_binary_file_body(self):
-        self.addCleanup(os_helper.unlink, os_helper.TESTFN)
-        with open(os_helper.TESTFN, "wb") as f:
+        self.addCleanup(support.unlink, support.TESTFN)
+        with open(support.TESTFN, "wb") as f:
             f.write(b"body\xc1")
-        with open(os_helper.TESTFN, "rb") as f:
+        with open(support.TESTFN, "rb") as f:
             self.conn.request("PUT", "/url", f)
             message, f = self.get_headers_and_fp()
             self.assertEqual("text/plain", message.get_content_type())
@@ -2187,12 +1987,11 @@ class HTTPResponseTest(TestCase):
 class TunnelTests(TestCase):
     def setUp(self):
         response_text = (
-            'HTTP/1.1 200 OK\r\n\r\n' # Reply to CONNECT
+            'HTTP/1.0 200 OK\r\n\r\n' # Reply to CONNECT
             'HTTP/1.1 200 OK\r\n' # Reply to HEAD
             'Content-Length: 42\r\n\r\n'
         )
         self.host = 'proxy.com'
-        self.port = client.HTTP_PORT
         self.conn = client.HTTPConnection(self.host)
         self.conn._create_connection = self._create_connection(response_text)
 
@@ -2204,45 +2003,15 @@ class TunnelTests(TestCase):
             return FakeSocket(response_text, host=address[0], port=address[1])
         return create_connection
 
-    def test_set_tunnel_host_port_headers_add_host_missing(self):
+    def test_set_tunnel_host_port_headers(self):
         tunnel_host = 'destination.com'
         tunnel_port = 8888
         tunnel_headers = {'User-Agent': 'Mozilla/5.0 (compatible, MSIE 11)'}
-        tunnel_headers_after = tunnel_headers.copy()
-        tunnel_headers_after['Host'] = '%s:%d' % (tunnel_host, tunnel_port)
         self.conn.set_tunnel(tunnel_host, port=tunnel_port,
                              headers=tunnel_headers)
         self.conn.request('HEAD', '/', '')
         self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertEqual(self.conn._tunnel_host, tunnel_host)
-        self.assertEqual(self.conn._tunnel_port, tunnel_port)
-        self.assertEqual(self.conn._tunnel_headers, tunnel_headers_after)
-
-    def test_set_tunnel_host_port_headers_set_host_identical(self):
-        tunnel_host = 'destination.com'
-        tunnel_port = 8888
-        tunnel_headers = {'User-Agent': 'Mozilla/5.0 (compatible, MSIE 11)',
-                          'Host': '%s:%d' % (tunnel_host, tunnel_port)}
-        self.conn.set_tunnel(tunnel_host, port=tunnel_port,
-                             headers=tunnel_headers)
-        self.conn.request('HEAD', '/', '')
-        self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertEqual(self.conn._tunnel_host, tunnel_host)
-        self.assertEqual(self.conn._tunnel_port, tunnel_port)
-        self.assertEqual(self.conn._tunnel_headers, tunnel_headers)
-
-    def test_set_tunnel_host_port_headers_set_host_different(self):
-        tunnel_host = 'destination.com'
-        tunnel_port = 8888
-        tunnel_headers = {'User-Agent': 'Mozilla/5.0 (compatible, MSIE 11)',
-                          'Host': '%s:%d' % ('example.com', 4200)}
-        self.conn.set_tunnel(tunnel_host, port=tunnel_port,
-                             headers=tunnel_headers)
-        self.conn.request('HEAD', '/', '')
-        self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
+        self.assertEqual(self.conn.sock.port, client.HTTP_PORT)
         self.assertEqual(self.conn._tunnel_host, tunnel_host)
         self.assertEqual(self.conn._tunnel_port, tunnel_port)
         self.assertEqual(self.conn._tunnel_headers, tunnel_headers)
@@ -2254,96 +2023,17 @@ class TunnelTests(TestCase):
                           'destination.com')
 
     def test_connect_with_tunnel(self):
-        d = {
-            b'host': b'destination.com',
-            b'port': client.HTTP_PORT,
-        }
-        self.conn.set_tunnel(d[b'host'].decode('ascii'))
-        self.conn.request('HEAD', '/', '')
-        self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertIn(b'CONNECT %(host)s:%(port)d HTTP/1.1\r\n'
-                      b'Host: %(host)s:%(port)d\r\n\r\n' % d,
-                      self.conn.sock.data)
-        self.assertIn(b'HEAD / HTTP/1.1\r\nHost: %(host)s\r\n' % d,
-                      self.conn.sock.data)
-
-    def test_connect_with_tunnel_with_default_port(self):
-        d = {
-            b'host': b'destination.com',
-            b'port': client.HTTP_PORT,
-        }
-        self.conn.set_tunnel(d[b'host'].decode('ascii'), port=d[b'port'])
-        self.conn.request('HEAD', '/', '')
-        self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertIn(b'CONNECT %(host)s:%(port)d HTTP/1.1\r\n'
-                      b'Host: %(host)s:%(port)d\r\n\r\n' % d,
-                      self.conn.sock.data)
-        self.assertIn(b'HEAD / HTTP/1.1\r\nHost: %(host)s\r\n' % d,
-                      self.conn.sock.data)
-
-    def test_connect_with_tunnel_with_nonstandard_port(self):
-        d = {
-            b'host': b'destination.com',
-            b'port': 8888,
-        }
-        self.conn.set_tunnel(d[b'host'].decode('ascii'), port=d[b'port'])
-        self.conn.request('HEAD', '/', '')
-        self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertIn(b'CONNECT %(host)s:%(port)d HTTP/1.1\r\n'
-                      b'Host: %(host)s:%(port)d\r\n\r\n' % d,
-                      self.conn.sock.data)
-        self.assertIn(b'HEAD / HTTP/1.1\r\nHost: %(host)s:%(port)d\r\n' % d,
-                      self.conn.sock.data)
-
-    # This request is not RFC-valid, but it's been possible with the library
-    # for years, so don't break it unexpectedly... This also tests
-    # case-insensitivity when injecting Host: headers if they're missing.
-    def test_connect_with_tunnel_with_different_host_header(self):
-        d = {
-            b'host': b'destination.com',
-            b'tunnel_host_header': b'example.com:9876',
-            b'port': client.HTTP_PORT,
-        }
-        self.conn.set_tunnel(
-            d[b'host'].decode('ascii'),
-            headers={'HOST': d[b'tunnel_host_header'].decode('ascii')})
-        self.conn.request('HEAD', '/', '')
-        self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertIn(b'CONNECT %(host)s:%(port)d HTTP/1.1\r\n'
-                      b'HOST: %(tunnel_host_header)s\r\n\r\n' % d,
-                      self.conn.sock.data)
-        self.assertIn(b'HEAD / HTTP/1.1\r\nHost: %(host)s\r\n' % d,
-                      self.conn.sock.data)
-
-    def test_connect_with_tunnel_different_host(self):
-        d = {
-            b'host': b'destination.com',
-            b'port': client.HTTP_PORT,
-        }
-        self.conn.set_tunnel(d[b'host'].decode('ascii'))
-        self.conn.request('HEAD', '/', '')
-        self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertIn(b'CONNECT %(host)s:%(port)d HTTP/1.1\r\n'
-                      b'Host: %(host)s:%(port)d\r\n\r\n' % d,
-                      self.conn.sock.data)
-        self.assertIn(b'HEAD / HTTP/1.1\r\nHost: %(host)s\r\n' % d,
-                      self.conn.sock.data)
-
-    def test_connect_with_tunnel_idna(self):
-        dest = '\u03b4\u03c0\u03b8.gr'
-        dest_port = b'%s:%d' % (dest.encode('idna'), client.HTTP_PORT)
-        expected = b'CONNECT %s HTTP/1.1\r\nHost: %s\r\n\r\n' % (
-            dest_port, dest_port)
-        self.conn.set_tunnel(dest)
+        self.conn.set_tunnel('destination.com')
         self.conn.request('HEAD', '/', '')
         self.assertEqual(self.conn.sock.host, self.host)
         self.assertEqual(self.conn.sock.port, client.HTTP_PORT)
-        self.assertIn(expected, self.conn.sock.data)
+        self.assertIn(b'CONNECT destination.com', self.conn.sock.data)
+        # issue22095
+        self.assertNotIn(b'Host: destination.com:None', self.conn.sock.data)
+        self.assertIn(b'Host: destination.com', self.conn.sock.data)
+
+        # This test should be removed when CONNECT gets the HTTP/1.1 blessing
+        self.assertNotIn(b'Host: proxy.com', self.conn.sock.data)
 
     def test_tunnel_connect_single_send_connection_setup(self):
         """Regresstion test for https://bugs.python.org/issue43332."""
@@ -2363,19 +2053,12 @@ class TunnelTests(TestCase):
                 msg=f'unexpected proxy data sent {proxy_setup_data_sent!r}')
 
     def test_connect_put_request(self):
-        d = {
-            b'host': b'destination.com',
-            b'port': client.HTTP_PORT,
-        }
-        self.conn.set_tunnel(d[b'host'].decode('ascii'))
+        self.conn.set_tunnel('destination.com')
         self.conn.request('PUT', '/', '')
         self.assertEqual(self.conn.sock.host, self.host)
-        self.assertEqual(self.conn.sock.port, self.port)
-        self.assertIn(b'CONNECT %(host)s:%(port)d HTTP/1.1\r\n'
-                      b'Host: %(host)s:%(port)d\r\n\r\n' % d,
-                      self.conn.sock.data)
-        self.assertIn(b'PUT / HTTP/1.1\r\nHost: %(host)s\r\n' % d,
-                      self.conn.sock.data)
+        self.assertEqual(self.conn.sock.port, client.HTTP_PORT)
+        self.assertIn(b'CONNECT destination.com', self.conn.sock.data)
+        self.assertIn(b'Host: destination.com', self.conn.sock.data)
 
     def test_tunnel_debuglog(self):
         expected_header = 'X-Dummy: 1'
@@ -2390,43 +2073,6 @@ class TunnelTests(TestCase):
         lines = output.getvalue().splitlines()
         self.assertIn('header: {}'.format(expected_header), lines)
 
-    def test_proxy_response_headers(self):
-        expected_header = ('X-Dummy', '1')
-        response_text = (
-            'HTTP/1.0 200 OK\r\n'
-            '{0}\r\n\r\n'.format(':'.join(expected_header))
-        )
-
-        self.conn._create_connection = self._create_connection(response_text)
-        self.conn.set_tunnel('destination.com')
-
-        self.conn.request('PUT', '/', '')
-        headers = self.conn.get_proxy_response_headers()
-        self.assertIn(expected_header, headers.items())
-
-    def test_tunnel_leak(self):
-        sock = None
-
-        def _create_connection(address, timeout=None, source_address=None):
-            nonlocal sock
-            sock = FakeSocket(
-                'HTTP/1.1 404 NOT FOUND\r\n\r\n',
-                host=address[0],
-                port=address[1],
-            )
-            return sock
-
-        self.conn._create_connection = _create_connection
-        self.conn.set_tunnel('destination.com')
-        exc = None
-        try:
-            self.conn.request('HEAD', '/', '')
-        except OSError as e:
-            # keeping a reference to exc keeps response alive in the traceback
-            exc = e
-        self.assertIsNotNone(exc)
-        self.assertTrue(sock.file_closed)
-
 
 if __name__ == '__main__':
     unittest.main(verbosity=2)
